Module: FileUtils
- Defined in:
- lib/sevgi/binaries/rake.rb
Overview
Extends FileUtils with Sevgi script helpers for Rake tasks.
Instance Method Summary collapse
-
#sevgi(file, *args, **kwargs) ⇒ Sevgi::Executor::Scope?
Thin DSL wrapper to call a script without spawning a shell.
Instance Method Details
#sevgi(file, *args, **kwargs) ⇒ Sevgi::Executor::Scope?
Thin DSL wrapper to call a script without spawning a shell.
13 14 15 16 17 18 19 20 |
# File 'lib/sevgi/binaries/rake.rb', line 13 def sevgi(file, *args, **kwargs) Sevgi.execute_file(F.existing!(file, [EXTENSION])) do |mod| include(Sevgi) mod.const_set(:ARGA, args).freeze mod.const_set(:ARGH, kwargs).freeze end end |